==> Epics9.161.tar.gz: Epics9.161/prog/epbndry2.f <==
      subroutine epbndry2(cnx, el, icon)
       implicit none
#include  "ZepTrackv.h"
#include  "Zcnfig.h"
c
c          get the length to the nearest crossing point of cTrack
c          and the specified component
c
        integer cnx   ! input. cnx-th component is examined
        real*8  el    ! output. length to the boundary of the cnx-th  comp
                      !         from cTrack.
        integer icon  ! output. 0, x,y,z is inside
                      !         1  outside,
                      !        -1  no Xssing

        record /epPos/ posw, posl
        record /epDirec/ dirw, dirl


        character*80 msg
        character*8  epparaphrase, tempph
        integer uscl
         if(Cn .eq. cnx) then
c            no need to conv. to local.coor.
           posl =cTrack.pos
           dirl =cTrack.w 
        else
           call epl2w(Cn, cTrack.pos, posw)
           call epw2l(cnx, posw, posl)
           call epl2wd(Cn, cTrack.w, dirw)
           call epw2ld(cnx, dirw, dirl)
        endif

        if(Det.cmp(cnx).struc(1:3) .eq. 'box') then
           call epbbox(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(Det.cmp(cnx).struc(1:3) .eq. 'cyl') then
           call epbcyl(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(Det.cmp(cnx).struc(1:4) .eq. 'pipe') then
           call epbpip(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(Det.cmp(cnx).struc .eq. 'prism' .or.
     *         Det.cmp(cnx).struc(1:6) .eq. 'prism_') then
           call epbprs(Det.cmp(cnx), posl, dirl,  el, icon)
        elseif(Det.cmp(cnx).struc(1:6) .eq. 'sphere') then
           call epbsph(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(Det.cmp(cnx).struc(1:4) .eq. 'new-') then
           call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
        else
           call epseeUnderScore(Det.cmp(cnx).struc, uscl)
           tempph = epparaphrase(Det.cmp(cnx).struc(1:uscl))
           if(tempph(1:4) .eq. 'new-') then
              call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
           else
c                   
              write(msg, *) ' strange structure=',
     *             Det.cmp(cnx).struc
              call cerrorMsg(msg, 0)
           endif
        endif
        end

==> Epics9.164.tar.gz: Epics9.164/prog/epbndry2.f <==
      subroutine epbndry2(cnx, el, icon)
       implicit none
#include  "ZepTrackv.h"
#include  "Zcnfig.h"
c
c          get the length to the nearest crossing point of cTrack
c          and the specified component
c
        integer cnx   ! input. cnx-th component is examined
        real*8  el    ! output. length to the boundary of the cnx-th  comp
                      !         from cTrack.
        integer icon  ! output. 0, x,y,z is inside
                      !         1  outside,
                      !        -1  no Xssing

        record /epPos/ posw, posl
        record /epDirec/ dirw, dirl


        character*80 msg
        character(len=MAX_STRUCCHR):: epparaphrase, tempph
        character(len=MAX_STRUCCHR):: basename
        integer uscl
         if(Cn .eq. cnx) then
c            no need to conv. to local.coor.
           posl =cTrack.pos
           dirl =cTrack.w 
        else
           call epl2w(Cn, cTrack.pos, posw)
           call epw2l(cnx, posw, posl)
           call epl2wd(Cn, cTrack.w, dirw)
           call epw2ld(cnx, dirw, dirl)
        endif

        call epGetBaseStrucName(Det.cmp(cnx).struc, basename)
        
        if(basename .eq. 'box') then
           call epbbox(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(basename .eq. 'cyl') then
           call epbcyl(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(basename .eq. 'pipe') then
           call epbpip(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(basename .eq. 'prism' ) then
           call epbprs(Det.cmp(cnx), posl, dirl,  el, icon)
        elseif(basename .eq. 'sphere') then
           call epbsph(Det.cmp(cnx), posl, dirl, el, icon)
        elseif(Det.cmp(cnx).struc(1:4) .eq. 'new-') then
           call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
        else
           call epseeUnderScore(Det.cmp(cnx).struc, uscl)
           tempph = epparaphrase(Det.cmp(cnx).struc(1:uscl))
           if(tempph(1:4) .eq. 'new-') then
              call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
           else
c                   
              write(msg, *) ' strange structure=',
     *             Det.cmp(cnx).struc
              call cerrorMsg(msg, 0)
           endif
        endif
        end
